Class: RecombeeApiClient::DeleteManualReqlSegment
- Inherits:
-
ApiRequest
- Object
- ApiRequest
- RecombeeApiClient::DeleteManualReqlSegment
- Defined in:
- lib/recombee_api_client/api/delete_manual_reql_segment.rb
Overview
Delete a Segment from a Manual ReQL Segmentation.
Instance Attribute Summary collapse
-
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
-
#segment_id ⇒ Object
readonly
Returns the value of attribute segment_id.
-
#segmentation_id ⇒ Object
readonly
Returns the value of attribute segmentation_id.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
Instance Method Summary collapse
-
#body_parameters ⇒ Object
Values of body parameters as a Hash.
-
#initialize(segmentation_id, segment_id) ⇒ DeleteManualReqlSegment
constructor
-
*Required arguments* -
segmentation_id-> ID of the Segmentation from which the Segment should be deleted -segment_id-> ID of the Segment that should be deleted.
-
-
#method ⇒ Object
HTTP method.
-
#path ⇒ Object
Relative path to the endpoint.
-
#query_parameters ⇒ Object
Values of query parameters as a Hash.
Methods included from HashNormalizer
#camelize, #normalize_hash_to_camel_case
Constructor Details
#initialize(segmentation_id, segment_id) ⇒ DeleteManualReqlSegment
-
*Required arguments*
-
segmentation_id-> ID of the Segmentation from which the Segment should be deleted -
segment_id-> ID of the Segment that should be deleted
-
21 22 23 24 25 26 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 21 def initialize(segmentation_id, segment_id) @segmentation_id = segmentation_id @segment_id = segment_id @timeout = 10_000 @ensure_https = false end |
Instance Attribute Details
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
14 15 16 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 14 def ensure_https @ensure_https end |
#segment_id ⇒ Object (readonly)
Returns the value of attribute segment_id.
13 14 15 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 13 def segment_id @segment_id end |
#segmentation_id ⇒ Object (readonly)
Returns the value of attribute segmentation_id.
13 14 15 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 13 def segmentation_id @segmentation_id end |
#timeout ⇒ Object
Returns the value of attribute timeout.
14 15 16 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 14 def timeout @timeout end |
Instance Method Details
#body_parameters ⇒ Object
Values of body parameters as a Hash
34 35 36 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 34 def body_parameters {} end |
#method ⇒ Object
HTTP method
29 30 31 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 29 def method :delete end |
#path ⇒ Object
Relative path to the endpoint
45 46 47 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 45 def path "/{databaseId}/segmentations/manual-reql/#{@segmentation_id}/segments/#{@segment_id}" end |
#query_parameters ⇒ Object
Values of query parameters as a Hash. name of parameter => value of the parameter
40 41 42 |
# File 'lib/recombee_api_client/api/delete_manual_reql_segment.rb', line 40 def query_parameters {} end |