Class: RecombeeApiClient::ListItemPurchases
- Inherits:
-
ApiRequest
- Object
- ApiRequest
- RecombeeApiClient::ListItemPurchases
- Defined in:
- lib/recombee_api_client/api/list_item_purchases.rb
Overview
Lists all the ever-made purchases of the given item.#
Instance Attribute Summary collapse
-
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
-
#item_id ⇒ Object
readonly
Returns the value of attribute item_id.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
Instance Method Summary collapse
-
#body_parameters ⇒ Object
Values of body parameters as a Hash.
-
#initialize(item_id) ⇒ ListItemPurchases
constructor
-
*Required arguments* -
item_id-> ID of the item whose purchases are to be listed.
-
-
#method ⇒ Object
HTTP method.
-
#path ⇒ Object
Relative path to the endpoint.
-
#query_parameters ⇒ Object
Values of query parameters as a Hash.
Methods included from HashNormalizer
#camelize, #normalize_hash_to_camel_case
Constructor Details
#initialize(item_id) ⇒ ListItemPurchases
-
*Required arguments*
-
item_id-> ID of the item whose purchases are to be listed.
-
20 21 22 23 24 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 20 def initialize(item_id) @item_id = item_id @timeout = 100_000 @ensure_https = false end |
Instance Attribute Details
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
13 14 15 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 13 def ensure_https @ensure_https end |
#item_id ⇒ Object (readonly)
Returns the value of attribute item_id.
12 13 14 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 12 def item_id @item_id end |
#timeout ⇒ Object
Returns the value of attribute timeout.
13 14 15 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 13 def timeout @timeout end |
Instance Method Details
#body_parameters ⇒ Object
Values of body parameters as a Hash
32 33 34 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 32 def body_parameters {} end |
#method ⇒ Object
HTTP method
27 28 29 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 27 def method :get end |
#path ⇒ Object
Relative path to the endpoint
43 44 45 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 43 def path "/{databaseId}/items/#{@item_id}/purchases/" end |
#query_parameters ⇒ Object
Values of query parameters as a Hash. name of parameter => value of the parameter
38 39 40 |
# File 'lib/recombee_api_client/api/list_item_purchases.rb', line 38 def query_parameters {} end |