Class: RecombeeApiClient::ListSeriesItems
- Inherits:
-
ApiRequest
- Object
- ApiRequest
- RecombeeApiClient::ListSeriesItems
- Defined in:
- lib/recombee_api_client/api/list_series_items.rb
Overview
Lists all the items present in the given series, sorted according to their time index values.#
Instance Attribute Summary collapse
-
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
-
#series_id ⇒ Object
readonly
Returns the value of attribute series_id.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
Instance Method Summary collapse
-
#body_parameters ⇒ Object
Values of body parameters as a Hash.
-
#initialize(series_id) ⇒ ListSeriesItems
constructor
-
*Required arguments* -
series_id-> ID of the series whose items are to be listed.
-
-
#method ⇒ Object
HTTP method.
-
#path ⇒ Object
Relative path to the endpoint.
-
#query_parameters ⇒ Object
Values of query parameters as a Hash.
Methods included from HashNormalizer
#camelize, #normalize_hash_to_camel_case
Constructor Details
#initialize(series_id) ⇒ ListSeriesItems
-
*Required arguments*
-
series_id-> ID of the series whose items are to be listed.
-
19 20 21 22 23 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 19 def initialize(series_id) @series_id = series_id @timeout = 100_000 @ensure_https = false end |
Instance Attribute Details
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
13 14 15 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 13 def ensure_https @ensure_https end |
#series_id ⇒ Object (readonly)
Returns the value of attribute series_id.
12 13 14 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 12 def series_id @series_id end |
#timeout ⇒ Object
Returns the value of attribute timeout.
13 14 15 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 13 def timeout @timeout end |
Instance Method Details
#body_parameters ⇒ Object
Values of body parameters as a Hash
31 32 33 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 31 def body_parameters {} end |
#method ⇒ Object
HTTP method
26 27 28 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 26 def method :get end |
#path ⇒ Object
Relative path to the endpoint
42 43 44 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 42 def path "/{databaseId}/series/#{@series_id}/items/" end |
#query_parameters ⇒ Object
Values of query parameters as a Hash. name of parameter => value of the parameter
37 38 39 |
# File 'lib/recombee_api_client/api/list_series_items.rb', line 37 def query_parameters {} end |