Class: RecombeeApiClient::RecommendUsersToUser

Inherits:
ApiRequest
  • Object
show all
Defined in:
lib/recombee_api_client/api/recommend_users_to_user.rb

Overview

Gets users similar to the given user, based on the user’s past interactions (purchases, ratings, etc.) and values of properties.

It is also possible to use POST HTTP method (for example in the case of a very long ReQL filter) - query parameters then become body parameters.

The returned users are sorted by similarity (the first user being the most similar).

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from HashNormalizer

#camelize, #normalize_hash_to_camel_case

Constructor Details

#initialize(user_id, count, optional = {}) ⇒ RecommendUsersToUser

  • *Required arguments*

    • user_id -> User to whom we find similar users

    • count -> Number of users to be recommended (N for the top-N recommendation).

  • *Optional arguments (given as hash optional)*

    • scenario -> Scenario defines a particular application of recommendations. It can be, for example, “homepage”, “cart”, or “emailing”.

You can set various settings to the [scenario](docs.recombee.com/scenarios) in the [Admin UI](admin.recombee.com). You can also see the performance of each scenario in the Admin UI separately, so you can check how well each application performs.

The AI that optimizes models to get the best results may optimize different scenarios separately or even use different models in each of the scenarios.

- +cascadeCreate+ -> If the user does not exist in the database, returns a list of non-personalized recommendations and creates the user in the database. This allows, for example, rotations in the following recommendations for that user, as the user will be already known to the system.
- +returnProperties+ -> With `returnProperties=true`, property values of the recommended users are returned along with their IDs in a JSON dictionary. The acquired property values can be used to easily display the recommended users.

Example response: “‘json

{
  "recommId": "9cb9c55d-50ba-4478-84fd-ab456136156e",
  "recomms":
    [
      {
        "id": "user-17",
        "values": {
          "country": "US",
          "sex": "F"
        }
      },
      {
        "id": "user-2",
        "values": {
          "country": "CAN",
          "sex": "M"
        }
      }
    ],
  "numberNextRecommsCalls": 0
}

“‘

- +includedProperties+ -> Allows specifying which properties should be returned when `returnProperties=true` is set. The properties are given as a comma-separated list.

Example response for ‘includedProperties=country`: “`json

{
  "recommId": "b326d82d-5d57-4b45-b362-c9d6f0895855",
  "recomms":
    [
      {
        "id": "user-17",
        "values": {
          "country": "US"
        }
      },
      {
        "id": "user-2",
        "values": {
          "country": "CAN"
        }
      }
    ],
  "numberNextRecommsCalls": 0
}

“‘

- +filter+ -> Boolean-returning [ReQL](https://docs.recombee.com/reql) expression, which allows you to filter recommended users based on the values of their attributes.

Filters can also be assigned to a [scenario](docs.recombee.com/scenarios) in the [Admin UI](admin.recombee.com).

- +booster+ -> Number-returning [ReQL](https://docs.recombee.com/reql) expression, which allows you to boost the recommendation rate of some users based on the values of their attributes.

Boosters can also be assigned to a [scenario](docs.recombee.com/scenarios) in the [Admin UI](admin.recombee.com).

- +logic+ -> Logic specifies the particular behavior of the recommendation models. You can pick tailored logic for your domain and use case.

See [this section](docs.recombee.com/recommendation_logics) for a list of available logics and other details.

The difference between logic and scenario is that logic specifies mainly behavior, while scenario specifies the place where recommendations are shown to the users.

Logic can also be set to a [scenario](docs.recombee.com/scenarios) in the [Admin UI](admin.recombee.com).

- +reqlExpressions+ -> A dictionary of [ReQL](https://docs.recombee.com/reql) expressions that will be executed for each recommended user.

This can be used to compute additional properties of the recommended users that are not stored in the database.

The keys are the names of the expressions, and the values are the actual ReQL expressions.

Example request: “‘json {

"reqlExpressions": {
  "isInUsersCity": "context_user[\"city\"] in 'cities'",
  "distanceToUser": "earth_distance('location', context_user[\"location\"])"
}

} “‘

Example response: “‘json {

"recommId": "ce52ada4-e4d9-4885-943c-407db2dee837",
"recomms":
  [
    {
      "id": "restaurant-178",
      "reqlEvaluations": {
        "isInUsersCity": true,
        "distanceToUser": 5200.2
      }
    },
    {
      "id": "bar-42",
      "reqlEvaluations": {
        "isInUsersCity": false,
        "distanceToUser": 2516.0
      }
    }
  ],
 "numberNextRecommsCalls": 0

} “‘

- +diversity+ -> **Expert option:** Real number from [0.0, 1.0], which determines how mutually dissimilar the recommended users should be. The default value is 0.0, i.e., no diversification. Value 1.0 means maximal diversification.

- +minRelevance+ -> **Expert option:** Specifies the threshold of how relevant must the recommended users be. Possible values one of: "low", "medium", "high".

- +rotationRate+ -> **Expert option:** If your users browse the system in real-time, it may easily happen that you wish to offer them recommendations multiple times. Here comes the question: how much should the recommendations change? Should they remain the same, or should they rotate? Recombee API allows you to control this per request in a backward fashion. You may penalize a user for being recommended in the near past. For the specific user, `rotationRate=1` means maximal rotation, `rotationRate=0` means absolutely no rotation. You may also use, for example, `rotationRate=0.2` for only slight rotation of recommended users.

- +rotationTime+ -> **Expert option:** Taking *rotationRate* into account, specifies how long it takes for a user to recover from the penalization. For example, `rotationTime=7200.0` means that users recommended less than 2 hours ago are penalized.

- +expertSettings+ -> Dictionary of custom options.

- +returnAbGroup+ -> If there is a custom AB-testing running, return the name of the group to which the request belongs.


154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 154

def initialize(user_id, count, optional = {})
  @user_id = user_id
  @count = count
  optional = normalize_hash_to_camel_case(optional)
  @scenario = optional['scenario']
  @cascade_create = optional['cascadeCreate']
  @return_properties = optional['returnProperties']
  @included_properties = optional['includedProperties']
  @filter = optional['filter']
  @booster = optional['booster']
  @logic = optional['logic']
  @reql_expressions = optional['reqlExpressions']
  @diversity = optional['diversity']
  @min_relevance = optional['minRelevance']
  @rotation_rate = optional['rotationRate']
  @rotation_time = optional['rotationTime']
  @expert_settings = optional['expertSettings']
  @return_ab_group = optional['returnAbGroup']
  @optional = optional
  @timeout = 50_000
  @ensure_https = false
  @optional.each do |par, _|
    raise UnknownOptionalParameter.new(par) unless %w[scenario cascadeCreate returnProperties
                                                      includedProperties filter booster logic reqlExpressions diversity minRelevance rotationRate rotationTime expertSettings returnAbGroup].include? par
  end
end

Instance Attribute Details

#boosterObject (readonly)

Returns the value of attribute booster.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def booster
  @booster
end

#cascade_createObject (readonly)

Returns the value of attribute cascade_create.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def cascade_create
  @cascade_create
end

#countObject (readonly)

Returns the value of attribute count.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def count
  @count
end

#diversityObject (readonly)

Returns the value of attribute diversity.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def diversity
  @diversity
end

#ensure_httpsObject

Returns the value of attribute ensure_https.



19
20
21
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 19

def ensure_https
  @ensure_https
end

#expert_settingsObject (readonly)

Returns the value of attribute expert_settings.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def expert_settings
  @expert_settings
end

#filterObject (readonly)

Returns the value of attribute filter.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def filter
  @filter
end

#included_propertiesObject (readonly)

Returns the value of attribute included_properties.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def included_properties
  @included_properties
end

#logicObject (readonly)

Returns the value of attribute logic.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def logic
  @logic
end

#min_relevanceObject (readonly)

Returns the value of attribute min_relevance.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def min_relevance
  @min_relevance
end

#reql_expressionsObject (readonly)

Returns the value of attribute reql_expressions.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def reql_expressions
  @reql_expressions
end

#return_ab_groupObject (readonly)

Returns the value of attribute return_ab_group.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def return_ab_group
  @return_ab_group
end

#return_propertiesObject (readonly)

Returns the value of attribute return_properties.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def return_properties
  @return_properties
end

#rotation_rateObject (readonly)

Returns the value of attribute rotation_rate.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def rotation_rate
  @rotation_rate
end

#rotation_timeObject (readonly)

Returns the value of attribute rotation_time.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def rotation_time
  @rotation_time
end

#scenarioObject (readonly)

Returns the value of attribute scenario.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def scenario
  @scenario
end

#timeoutObject

Returns the value of attribute timeout.



19
20
21
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 19

def timeout
  @timeout
end

#user_idObject (readonly)

Returns the value of attribute user_id.



17
18
19
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 17

def user_id
  @user_id
end

Instance Method Details

#body_parametersObject

Values of body parameters as a Hash



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 187

def body_parameters
  p = {}
  p['count'] = @count
  p['scenario'] = @optional['scenario'] if @optional.include? 'scenario'
  p['cascadeCreate'] = @optional['cascadeCreate'] if @optional.include? 'cascadeCreate'
  p['returnProperties'] = @optional['returnProperties'] if @optional.include? 'returnProperties'
  p['includedProperties'] = @optional['includedProperties'] if @optional.include? 'includedProperties'
  p['filter'] = @optional['filter'] if @optional.include? 'filter'
  p['booster'] = @optional['booster'] if @optional.include? 'booster'
  p['logic'] = @optional['logic'] if @optional.include? 'logic'
  p['reqlExpressions'] = @optional['reqlExpressions'] if @optional.include? 'reqlExpressions'
  p['diversity'] = @optional['diversity'] if @optional.include? 'diversity'
  p['minRelevance'] = @optional['minRelevance'] if @optional.include? 'minRelevance'
  p['rotationRate'] = @optional['rotationRate'] if @optional.include? 'rotationRate'
  p['rotationTime'] = @optional['rotationTime'] if @optional.include? 'rotationTime'
  p['expertSettings'] = @optional['expertSettings'] if @optional.include? 'expertSettings'
  p['returnAbGroup'] = @optional['returnAbGroup'] if @optional.include? 'returnAbGroup'

  p
end

#methodObject

HTTP method



182
183
184
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 182

def method
  :post
end

#pathObject

Relative path to the endpoint



215
216
217
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 215

def path
  "/{databaseId}/recomms/users/#{@user_id}/users/"
end

#query_parametersObject

Values of query parameters as a Hash. name of parameter => value of the parameter



210
211
212
# File 'lib/recombee_api_client/api/recommend_users_to_user.rb', line 210

def query_parameters
  {}
end