Class: RecombeeApiClient::UpdatePropertyBasedSegmentation
- Inherits:
-
ApiRequest
- Object
- ApiRequest
- RecombeeApiClient::UpdatePropertyBasedSegmentation
- Defined in:
- lib/recombee_api_client/api/update_property_based_segmentation.rb
Overview
Updates a Property Based Segmentation
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
-
#property_name ⇒ Object
readonly
Returns the value of attribute property_name.
-
#segmentation_id ⇒ Object
readonly
Returns the value of attribute segmentation_id.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
-
#title ⇒ Object
readonly
Returns the value of attribute title.
Instance Method Summary collapse
-
#body_parameters ⇒ Object
Values of body parameters as a Hash.
-
#initialize(segmentation_id, optional = {}) ⇒ UpdatePropertyBasedSegmentation
constructor
-
*Required arguments* -
segmentation_id-> ID of the updated Segmentation.
-
-
#method ⇒ Object
HTTP method.
-
#path ⇒ Object
Relative path to the endpoint.
-
#query_parameters ⇒ Object
Values of query parameters as a Hash.
Methods included from HashNormalizer
#camelize, #normalize_hash_to_camel_case
Constructor Details
#initialize(segmentation_id, optional = {}) ⇒ UpdatePropertyBasedSegmentation
-
*Required arguments*
-
segmentation_id-> ID of the updated Segmentation
-
-
*Optional arguments (given as hash optional)*
-
propertyName-> Name of the property on which the Segmentation should be based -
title-> Human-readable name that is shown in the Recombee Admin UI. -
description-> Description that is shown in the Recombee Admin UI.
-
28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 28 def initialize(segmentation_id, optional = {}) @segmentation_id = segmentation_id optional = normalize_hash_to_camel_case(optional) @property_name = optional['propertyName'] @title = optional['title'] @description = optional['description'] @optional = optional @timeout = 10_000 @ensure_https = false @optional.each do |par, _| raise UnknownOptionalParameter.new(par) unless %w[propertyName title description].include? par end end |
Instance Attribute Details
#description ⇒ Object (readonly)
Returns the value of attribute description.
13 14 15 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 13 def description @description end |
#ensure_https ⇒ Object
Returns the value of attribute ensure_https.
14 15 16 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 14 def ensure_https @ensure_https end |
#property_name ⇒ Object (readonly)
Returns the value of attribute property_name.
13 14 15 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 13 def property_name @property_name end |
#segmentation_id ⇒ Object (readonly)
Returns the value of attribute segmentation_id.
13 14 15 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 13 def segmentation_id @segmentation_id end |
#timeout ⇒ Object
Returns the value of attribute timeout.
14 15 16 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 14 def timeout @timeout end |
#title ⇒ Object (readonly)
Returns the value of attribute title.
13 14 15 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 13 def title @title end |
Instance Method Details
#body_parameters ⇒ Object
Values of body parameters as a Hash
48 49 50 51 52 53 54 55 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 48 def body_parameters p = {} p['propertyName'] = @optional['propertyName'] if @optional.include? 'propertyName' p['title'] = @optional['title'] if @optional.include? 'title' p['description'] = @optional['description'] if @optional.include? 'description' p end |
#method ⇒ Object
HTTP method
43 44 45 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 43 def method :post end |
#path ⇒ Object
Relative path to the endpoint
64 65 66 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 64 def path "/{databaseId}/segmentations/property-based/#{@segmentation_id}" end |
#query_parameters ⇒ Object
Values of query parameters as a Hash. name of parameter => value of the parameter
59 60 61 |
# File 'lib/recombee_api_client/api/update_property_based_segmentation.rb', line 59 def query_parameters {} end |